@@ -52,8 +52,11 @@ def about():
         print("    Project repository refs = " + git_info["refs"])
 
 
-def test():
+def test(nodes = None):
     """Runs the testsuite (the short one)"""
     print("Running qocttools testsuite")
     testsuite_dir = os.path.join(os.path.dirname(__file__), 'tests')
-    pytest.main(["-v", os.path.join(testsuite_dir, "short.py")])
+    if nodes == None:
+        pytest.main(["-v", os.path.join(testsuite_dir, "short.py")])
+    else:
+        pytest.main(["-v", "-n {} ".format(nodes), os.path.join(testsuite_dir, "short.py")])
